import puppeteer from "puppeteer";
import { TemplateHelper } from "./templateHelper";
import { PermissionModule } from "../type/permissionTypes";

export abstract class PdfExport {
  static async renderFile({
    template,
    title = "pdf-export Mitgliederverwaltung",
    filename = null,
    data = {},
    saveToDisk = true,
    margins = { top: "15mm", bottom: "15mm" },
  }: {
    template: PermissionModule;
    title?: string;
    filename?: string;
    data?: any;
    saveToDisk?: boolean;
    margins?: { top: string; bottom: string };
  }) {
    const { header, footer, body } = await TemplateHelper.renderFileForModule({
      module: template,
      bodyData: data,
      title: title,
    });

    const browser = await puppeteer.launch({
      headless: true,
      args: ["--no-sandbox", "--disable-gpu", "--disable-setuid-sandbox"],
    });
    const page = await browser.newPage();
    await page.setContent(body, { waitUntil: "domcontentloaded" });

    let pdf = await page.pdf({
      ...(saveToDisk ? { path: process.cwd() + `/export/${filename}.pdf` } : {}),
      format: "A4",
      printBackground: false,
      margin: {
        top: margins.top,
        bottom: margins.bottom,
        left: "10mm",
        right: "10mm",
      },
      displayHeaderFooter: true,
      headerTemplate: header,
      footerTemplate: footer,
    });

    await browser.close();

    return pdf;
  }
}
